==> kde4libs_3.80.1.orig.tar.gz: kde4libs-3.80.1/sonnet/plugins/hspell/kspell_hspelldict.h <==
/**
 * kspell_hspelldict.h
 *
 * Copyright (C)  2003  Zack Rusin <zack@kde.org>
 * Copyright (C)  2005  Mashrab Kuvatov <kmashrab@uni-bremen.de>
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
 * 02110-1301  USA
 */
#ifndef KSPELL_HSPELLDICT_H
#define KSPELL_HSPELLDICT_H

#include "speller.h"
/* libhspell is a C library and it does not have #ifdef __cplusplus */
extern "C" {
#include "hspell.h"
}

class HSpellDict : public KSpell2::Speller
{
public:
    HSpellDict( const QString& lang );
    ~HSpellDict();
    virtual bool isCorrect( const QString& word ) const;

    virtual QStringList suggest( const QString& word ) const;

    virtual bool storeReplacement( const QString& bad,
                                   const QString& good );

    virtual bool addToPersonal( const QString& word );
    virtual bool addToSession( const QString& word );
private:
    struct dict_radix *m_speller;
    QTextCodec *codec;
};

#endif

==> kde4libs_3.80.3.orig.tar.gz: kde4libs-3.80.3/sonnet/plugins/hspell/kspell_hspelldict.h <==
/**
 * kspell_hspelldict.h
 *
 * Copyright (C)  2003  Zack Rusin <zack@kde.org>
 * Copyright (C)  2005  Mashrab Kuvatov <kmashrab@uni-bremen.de>
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
 * 02110-1301  USA
 */
#ifndef KSPELL_HSPELLDICT_H
#define KSPELL_HSPELLDICT_H

#include "speller.h"
/* libhspell is a C library and it does not have #ifdef __cplusplus */
extern "C" {
#include "hspell.h"
}

class HSpellDict : public KSpell2::Speller
{
public:
    explicit HSpellDict( const QString& lang );
    ~HSpellDict();
    virtual bool isCorrect( const QString& word ) const;

    virtual QStringList suggest( const QString& word ) const;

    virtual bool storeReplacement( const QString& bad,
                                   const QString& good );

    virtual bool addToPersonal( const QString& word );
    virtual bool addToSession( const QString& word );
private:
    struct dict_radix *m_speller;
    QTextCodec *codec;
};

#endif
